import { RemovalPolicy } from 'aws-cdk-lib';
import { ApplicationLoadBalancer } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
import { Key } from 'aws-cdk-lib/aws-kms';
import { LogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { CfnWebACL } from 'aws-cdk-lib/aws-wafv2';
import { Construct } from 'constructs';
export interface WebApplicationFirewallProps {
    /**
     * List of AWS Managed Rule Groups to use for the firewall
     * @default []
     */
    readonly awsManagedRuleGroups?: (WebApplicationFirewall.AwsManagedRuleGroupConfig | WebApplicationFirewall.AwsManagedRuleGroup)[];
    /**
     * Whether to enable CloudWatch metrics
     * @default false
     */
    readonly cloudWatchMetricsEnabled?: boolean;
    /**
     * Whether to enable sampled requests
     * @default false
     */
    readonly sampledRequestsEnabled?: boolean;
    /**
     * Logging configuration for the firewall
     */
    readonly logging?: WebApplicationFirewall.WebApplicationFirewallLoggingConfig;
}
/**
 * Creates an AWS Web Application Firewall (WAF) that can be associated with
 * resources such as an Application Load Balancer.
 *
 * It allows configuring AWS managed rule groups, logging, and visibility
 * settings. The construct simplifies the creation of a WAF by providing
 * available AWS managed rule groups that can be utilized.
 *
 * Currently, the only resource that is supported to associate the WAF with is
 * an ALB.
 *
 * @example
 *
 * import { ApplicationLoadBalancer } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
 * import { WebApplicationFirewall } from '@cdklabs/cdk-proserve-lib/constructs';
 *
 * const alb = new ApplicationLoadBalancer(this, 'Alb', { vpc });
 * const waf = new WebApplicationFirewall(this, 'WAF', {
 *   awsManagedRuleGroups: [
 *     WebApplicationFirewall.AwsManagedRuleGroup.COMMON_RULE_SET,
 *     WebApplicationFirewall.AwsManagedRuleGroup.LINUX_RULE_SET
 *   ]
 * });
 * waf.associate(alb);  // Associate the WAF with the ALB
 */
export declare class WebApplicationFirewall extends Construct {
    /**
     * The WAF Web ACL (Access Control List) resource
     */
    readonly webAcl: CfnWebACL;
    /**
     * Optional CloudWatch log group for WAF logging. This is available if you
     * have configured `logging` on the construct.
     */
    readonly logGroup?: LogGroup;
    /**
     * Configuration properties for WAF visibility settings including
     * CloudWatch metrics and sampled requests
     */
    private readonly visibilityConfigProps;
    /**
     * Creates an AWS Web Application Firewall (WAF) that can be associated with
     * resources such as an Application Load Balancer.
     *
     * @param scope The scope in which to define this construct
     * @param id The scoped construct ID
     * @param props Configuration properties
     */
    constructor(scope: Construct, id: string, props?: WebApplicationFirewallProps);
    /**
     * Associates the Web Application Firewall to an applicable resource.
     */
    associate(resource: ApplicationLoadBalancer): void;
    /**
     * Gets the corresponding RuleActionProperty for a given override action
     * @param action - The override action to convert
     * @returns The corresponding CfnWebACL.RuleActionProperty
     */
    private getOverrideActionProperty;
    /**
     * Builds WAF rules from the provided AWS managed rule groups
     * @param awsManagedRuleGroups - Array of rule group configurations or predefined rule groups
     * @returns Array of WAF rule properties
     */
    private buildRules;
    /**
     * Type guard to determine if a rule is an AwsManagedRuleGroupConfig
     * @param rule - The rule to check, can be either AwsManagedRuleGroupConfig or AwsManagedRuleGroup
     * @returns True if the rule is an AwsManagedRuleGroupConfig, false otherwise
     */
    private isAwsManagedRuleGroupConfig;
}
export declare namespace WebApplicationFirewall {
    interface WebApplicationFirewallLoggingConfig {
        /**
         * Log Group name affix to be appended to aws-waf-logs-<affix>
         */
        readonly logGroupNameAffix: string;
        /**
         * Retention period for the log group
         * @default ONE_MONTH
         */
        readonly retention?: RetentionDays;
        /**
         * Removal policy for the log group
         * @default DESTROY
         */
        readonly removalPolicy?: RemovalPolicy;
        /**
         * KMS key to use for encryption of the log group
         */
        readonly encryptionKey?: Key;
    }
    /** WAF Managed Rule Groups */
    enum AwsManagedRuleGroup {
        /** Contains rules that are generally applicable to web applications. This provides protection against exploitation of a wide range of vulnerabilities, including those described in OWASP publications. */
        COMMON_RULE_SET = "AWSManagedRulesCommonRuleSet",
        /** Contains rules that allow you to block external access to exposed admin pages. This may be useful if you are running third-party software or would like to reduce the risk of a malicious actor gaining administrative access to your application. */
        ADMIN_PROTECTION_RULE_SET = "AWSManagedRulesAdminProtectionRuleSet",
        /** Contains rules that allow you to block request patterns that are known to be invalid and are associated with exploitation or discovery of vulnerabilities. This can help reduce the risk of a malicious actor discovering a vulnerable application. */
        KNOWN_BAD_INPUTS_RULE_SET = "AWSManagedRulesKnownBadInputsRuleSet",
        /** Contains rules that allow you to block request patterns associated with exploitation of SQL databases, like SQL injection attacks. This can help prevent remote injection of unauthorized queries. */
        SQL_DATABASE_RULE_SET = "AWSManagedRulesSQLiRuleSet",
        /** Contains rules that block request patterns associated with exploitation of vulnerabilities specific to Linux, including LFI attacks. This can help prevent attacks that expose file contents or execute code for which the attacker should not have had access. */
        LINUX_RULE_SET = "AWSManagedRulesLinuxRuleSet",
        /** Contains rules that block request patterns associated with exploiting vulnerabilities specific to POSIX/POSIX-like OS, including LFI attacks. This can help prevent attacks that expose file contents or execute code for which access should not been allowed. */
        UNIX_RULE_SET = "AWSManagedRulesUnixRuleSet",
        /** Contains rules that block request patterns associated with exploiting vulnerabilities specific to Windows, (e.g., PowerShell commands). This can help prevent exploits that allow attacker to run unauthorized commands or execute malicious code. */
        WINDOWS_RULE_SET = "AWSManagedRulesWindowsRuleSet",
        /** Contains rules that block request patterns associated with exploiting vulnerabilities specific to the use of the PHP, including injection of unsafe PHP functions. This can help prevent exploits that allow an attacker to remotely execute code or commands. */
        PHP_RULE_SET = "AWSManagedRulesPHPRuleSet",
        /** The WordPress Applications group contains rules that block request patterns associated with the exploitation of vulnerabilities specific to WordPress sites. */
        WORD_PRESS_RULE_SET = "AWSManagedRulesWordPressRuleSet",
        /** This group contains rules that are based on Amazon threat intelligence. This is useful if you would like to block sources associated with bots or other threats. */
        AMAZON_IP_REPUTATION_LIST = "AWSManagedRulesAmazonIpReputationList",
        /** This group contains rules that allow you to block requests from services that allow obfuscation of viewer identity. This can include request originating from VPN, proxies, Tor nodes, and hosting providers. This is useful if you want to filter out viewers that may be trying to hide their identity from your application. */
        ANONYMOUS_IP_LIST = "AWSManagedRulesAnonymousIpList",
        /** Provides protection against automated bots that can consume excess resources, skew business metrics, cause downtime, or perform malicious activities. Bot Control provides additional visibility through Amazon CloudWatch and generates labels that you can use to control bot traffic to your applications. */
        BOT_CONTROL_RULE_SET = "AWSManagedRulesBotControlRuleSet",
        /** Provides protection for your login page against stolen credentials, credential stuffing attacks, brute force login attempts, and other anomalous login activities. With account takeover prevention, you can prevent unauthorized access that may lead to fraudulent activities, or inform legitimate users to take a preventive action. */
        ATP_RULE_SET = "AWSManagedRulesATPRuleSet",
        /** Provides protection against the creation of fraudulent accounts on your site. Fraudulent accounts can be used for activities such as obtaining sign-up bonuses and impersonating legitimate users. */
        ACFP_RULE_SET = "AWSManagedRulesACFPRuleSet"
    }
    /** End WAF Managed Rule Groups */
    /**
     * Enum representing possible override actions for WAF rules
     */
    enum OverrideAction {
        ALLOW = "ALLOW",
        BLOCK = "BLOCK",
        COUNT = "COUNT"
    }
    /**
     * Configuration for rule overrides
     */
    interface OverrideConfig {
        /**
         * The name of the specific rule to override
         */
        readonly name: string;
        /**
         * The action to take for the specific rule
         */
        readonly action: OverrideAction;
    }
    /**
     * Configuration interface for AWS Managed Rule Groups
     *
     * This interface allows you to specify a managed rule group and optionally
     * override the default actions for specific rules within that group.
     */
    interface AwsManagedRuleGroupConfig {
        /**
         * The AWS Managed Rule Group to apply
         */
        readonly ruleGroup: AwsManagedRuleGroup;
        /**
         * Optional list of rule action overrides
         */
        readonly ruleGroupActionOverrides?: OverrideConfig[];
    }
}
